diff --git a/scripts/start/prepare_and_run.R b/scripts/start/prepare_and_run.R
index 90c64e1cfd09da0e5df76bff57e030e3cb7ec98a..68d691e2ab66d19ad644013bc431a2c06cd90c8a 100644
--- a/scripts/start/prepare_and_run.R
+++ b/scripts/start/prepare_and_run.R
@@ -597,6 +597,18 @@ run <- function(start_subsequent_runs = TRUE) {
   # Save start time
   timeGAMSStart <- Sys.time()
   
+  # De-compress finxing files if they have already been zipped (only valid if run is restarted)
+  if (cfg$gms$cm_startyear > 2005) {
+      if (file.exists("levs.gms.gz")) {
+        cat("Unzip fixing files\n")
+        system("gzip -d -f levs.gms.gz margs.gms.gz fixings.gms.gz")
+      } else if (file.exists("levs.gms")) {
+        cat("Found unzipped fixing files. Using them.\n")
+      } else {
+        stop("cm_startyear > 2005 but no fixing files found, neither zipped or unzipped.")
+      }
+  }
+
   # Print message
   cat("\nStarting REMIND...\n")
 
diff --git a/start.R b/start.R
index 89230c8cdb4eb0161e39726337e50675f7842329..c793f8121ee446f81443d740fcada0155c874cb8 100755
--- a/start.R
+++ b/start.R
@@ -44,10 +44,10 @@ get_line <- function(){
 choose_folder <- function(folder,title="Please choose a folder") {
   dirs <- NULL
   
   # Detect all output folders containing fulldata.gdx
   # For coupled runs please use the outcommented text block below
 
-  dirs <- sub("/fulldata.gdx","",sub("./output/","",Sys.glob(file.path(folder,"*","fulldata.gdx"))))
+  dirs <- sub("/(non_optimal|fulldata).gdx","",sub("./output/","",Sys.glob(c(file.path(folder,"*","non_optimal.gdx"),file.path(folder,"*","fulldata.gdx")))))
 
   # DK: The following outcommented lines are specially made for listing results of coupled runs
   #runs <- findCoupledruns(folder)
@@ -44,10 +44,10 @@ get_line <- function(){
   dirs <- NULL
   
-  # Detect all output folders containing fulldata.gdx
+  # Detect all output folders containing fulldata.gdx or non_optimal.gdx
   # For coupled runs please use the outcommented text block below
 